@@ -1,5 +1,5 @@
 package Chemistry::Mol;
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 =head1 NAME
 
@@ -132,7 +132,7 @@ sub add_bond {
 
 Shorthand for $mol->add_bond(Chemistry::Bond->new(name => value, ...));
 It has the disadvantage that it doesn't let you create a subclass of 
-Chemistry::Atom.
+Chemistry::Bond.
 
 =cut
 
@@ -187,20 +187,6 @@ sub atoms_by_name {
     wantarray ? @ret : $ret[0];
 }
 
-=for comment
-sub select_atoms {
-    my $self = shift;
-    my %opts = @_;
-    my @a = $self->atoms;
-    for my $opt (keys %opts) {
-        my $re = qr/^$opts{$opt}$/;
-        @a = grep {$_->$opt =~ $re} @a;
-    }
-    @a;
-}
-
-=cut
-
 =item $mol->bonds($n1, ...)
 
 Returns the bonds with the given indices, or all by default.
@@ -334,6 +320,10 @@ sub write {
 Register a file type. The identifier $name must be unique.
 $ref is either a class name (a package) or an object that complies
 with the L<Chemistry::File> interface (e.g., a subclass of Chemistry::File).
+If $ref is omitted, the calling package is used automatically. More than one
+format can be registered at a time, but then $ref must be included for each
+format (e.g., Chemistry::Mol->register_format(format1 => "package1", format2 =>
+package2).
 
 The typical user doesn't have to care about this function. It is used
 automatically by molecule file I/O modules.
@@ -342,6 +332,10 @@ automatically by molecule file I/O modules.
 
 sub register_format {
     my $class = shift;
+    if (@_ == 1) {
+        $FILE_FORMATS{$_[0]} = caller;
+        return;
+    }
     my %opts = @_;
     $FILE_FORMATS{$_} = $opts{$_} for keys %opts;
 }
@@ -367,6 +361,51 @@ sub formats {
     }
 }
 
+=item $mol->mass
+
+Return the molar mass.
+
+=cut
+
+sub mass {
+    my ($self) = @_;
+    my $mass = 0;
+    for my $atom ($self->atoms) {
+        $mass += $atom->mass;
+    }
+    $mass;
+}
+
+=item $mol->formula_hash
+
+Returns a hash reference describing the molecular formula. For methane it would
+return { C => 1, H => 4 }.
+
+=cut
+
+sub formula_hash {
+    my ($self) = @_;
+    my $formula = {};
+    for my $atom ($self->atoms) {
+        $formula->{$atom->symbol}++;
+    }
+    $formula;
+}
+
+=item $mol->formula($format)
+
+Returns a string with the formula. The format can be specified as a printf-like
+string with the control sequences specified in the L<Chemistry::File::Formula>
+documentation.
+
+=cut
+
+sub formula {
+    my ($self, $format) = @_;
+    require Chemistry::File::Formula;
+    $self->print(format => "formula", formula_format => $format);
+}
+
 1;
 
 =back
